Send patches - preferably formatted by git format-patch - to patches at archlinux32 dot org.
summaryrefslogtreecommitdiff
path: root/profiles/kde.py
diff options
context:
space:
mode:
Diffstat (limited to 'profiles/kde.py')
-rw-r--r--profiles/kde.py5
1 files changed, 4 insertions, 1 deletions
diff --git a/profiles/kde.py b/profiles/kde.py
index 28460cbc..1c98237b 100644
--- a/profiles/kde.py
+++ b/profiles/kde.py
@@ -39,7 +39,10 @@ if __name__ == 'kde':
# Install dependency profiles
installation.install_profile('xorg')
- # Install the application kde from the template under /applications/
+ # Install the KDE packages
+ installation.add_additional_packages(__packages__)
+
+ # Run KDE application configuration
kde = archinstall.Application(installation, 'kde')
kde.install()